# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/crud/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/crud/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Crud\\": "packages/litepie/crud/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Crud\Providers\CrudServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Crud'  => Litepie\Crud\Facades\Crud::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\CrudTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Crud\Providers\CrudServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Crud\Providers\CrudServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Crud\Providers\CrudServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/crud/{modulename}

**User**

    http://path-to-route-folder/user/crud/{modulename}

**Public**

    http://path-to-route-folder/cruds


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/crud/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/crud/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/crud/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/crud/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/crud/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/crud/{modulename}/{slug}
    METHOD: GET