<?php

namespace Litepie\Crud\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Crud\Models\Cruds;

class CrudsPolicy
{

    /**
     * Determine if the given user can view the cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function view(UserPolicy $user, Cruds $cruds)
    {
        if ($user->canDo('crud.cruds.view') && $user->isAdmin()) {
            return true;
        }

        return $cruds->user_id == user_id() && $cruds->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('crud.cruds.create');
    }

    /**
     * Determine if the given user can update the given cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function update(UserPolicy $user, Cruds $cruds)
    {
        if ($user->canDo('crud.cruds.edit') && $user->isAdmin()) {
            return true;
        }

        return $cruds->user_id == user_id() && $cruds->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Cruds $cruds)
    {
        return $cruds->user_id == user_id() && $cruds->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Cruds $cruds)
    {
        if ($user->canDo('crud.cruds.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cruds.
     *
     * @param UserPolicy $user
     * @param Cruds $cruds
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Cruds $cruds)
    {
        if ($user->canDo('crud.cruds.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
